@@ -15,7 +15,7 @@ class Identifier:
         dist: Optional[Distribution] = None,
         key: Callable = Keys.NONE,
         reverse=False,
-        boundaryless: Optional[Filter] = None
+        boundaryless: Optional[Filter] = None,
     ):
         if dist is None:
             self.distribution = Distribution()
@@ -38,7 +38,8 @@ class Identifier:
         dist: Distribution = None,
         key: Optional[Callable] = None,
         reverse: Optional[bool] = None,
-        boundaryless: Optional[Filter] = None
+        boundaryless: Optional[Filter] = None,
+        include_filenames=False,
     ) -> dict:
         if dist is None:
             dist = self.distribution
@@ -48,6 +49,7 @@ class Identifier:
             reverse = self._reverse
         if boundaryless is None:
             boundaryless = self.boundaryless
+
         identify_obj = {"File Signatures": {}, "Regexes": {}}
         search = []
 
@@ -68,7 +70,10 @@ class Identifier:
 
                 magic_numbers = self._file_sig.open_binary_scan_magic_nums(string)
                 contents = self._file_sig.open_file_loc(string)
-                contents.append(os.path.basename(string))
+
+                if include_filenames:
+                    contents.append(os.path.basename(string))
+
                 regex = self._regex_id.check(contents, dist)
 
                 if not magic_numbers:
